# Changelog
All notable changes to this project are documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.4.4]
### Changed
- User Guide updates.
- Add work-around to `deploy aws` for issue with Orchestrator HTTP API.

## [0.4.3]
### Changed
- Fixes to `deploy aws`.

## [0.4.2]
### Changed
- Fixes to `deploy aws`.

## [0.4.1]
### Changed
- Fixes to `deploy aws`.

## [0.4.0]
### Added
- Added the `deploy aws` command.

## [0.3.0]
### Changed
- Fixes for product demo.

## [0.2.0]
### Added
- Added the `--credentials-file` option to the `login` command.

## [0.1.1] - 2018-08-31
### Changed
- No functional changes. Packaging change for [PyPi](https://pypi.org/).

## [0.1.0] - 2018-08-31
### Added
- Initial version of the CLI tool published to [PyPi](https://pypi.org/).
